@@ -1,4 +1,4 @@
-/***             analog 4.1             http://www.analog.cx/             ***/
+/***             analog 4.04             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -55,14 +55,22 @@ choice do_alias(char *name, Memman *mp, Alias *aliashead,
 }
 
 void do_aliasx(char *name, Alias *aliashead) {
-  ptrdiff_t pmatch[PMATCH_SIZE];
+  static regmatch_t pmatch[10];  /* we only allow up to 9 matches */
   Alias *ap;
+#ifndef NOREGEX
+  logical is_regex;
+#endif
   logical done = FALSE;
 
   for (ap = aliashead; ap != NULL && !done; TO_NEXT(ap)) {
-    if (matchq(name,
-	       (ap->isregex)?((void *)(ap->pattern)):((void *)(ap->from)),
-	       ap->isregex, pmatch)) {
+#ifdef NOREGEX
+    if (matchq(name, (void *)(ap->from), FALSE, ap->nmatch, pmatch)) {
+#else
+    is_regex = IS_REGEXN(ap->nmatch);
+    if (matchq(name, is_regex?((void *)(ap->pattern)):((void *)(ap->from)),
+	       is_regex,
+	       is_regex?DECODE_NMATCH(ap->nmatch):(ap->nmatch), pmatch)) {
+#endif
       done = TRUE;
       wildalias(name, ap->to, pmatch);
     }
@@ -77,8 +85,6 @@ logical do_aliasr(char *name,  char *dirsuffix, unsigned int dirsufflength) {
   char *c, *d, *e1, *e2;
   unsigned int tempint = 0;
 
-  /* NB Case insensitivity has been done (if necessary) in prealias() */
-
   /* Zerothly, strip off #'s. These shouldn't get in the request, but do
      for some broken agents (particularly spiders). */
   if ((c = strchr(name, '#')) != NULL)
@@ -572,9 +578,9 @@ void do_dns(char *name, char *alias, choice level) {
 }
 #endif
 
-void wildalias(char *name, AliasTo *to, ptrdiff_t pmatch[]) {
+void wildalias(char *name, AliasTo *to, regmatch_t pmatch[]) {
   char *s, *ans;
-  ptrdiff_t *pm;
+  regmatch_t *pm;
   /* Matching has already been checked. And assume that name is big enough
      to contain the result AFTER the orig name. */
   ans = name + strlen(name);  /* we will build answer here */
@@ -582,9 +588,10 @@ void wildalias(char *name, AliasTo *to, ptrdiff_t pmatch[]) {
     strcpy(s, to->string);
     s = strchr(s, '\0');
     pm = &(pmatch[to->after]);
-    if (to->after >= 0 && pm[0] >= 0) {
-      memcpy((void *)s, (void *)(name + pm[0]), (size_t)(pm[1] - pm[0]));
-      s += pm[1] - pm[0];
+    if (to->after >= 0 && pm->rm_so >= 0) {
+      memcpy((void *)s, (void *)(name + pm->rm_so),
+	     (size_t)(pm->rm_eo - pm->rm_so));
+      s += pm->rm_eo - pm->rm_so;
     }
   }
   *s = '\0';
@@ -638,15 +645,14 @@ choice prealias(Memman *mm, Memman *mmv, Hashentry *vhost, Memman *mmq,
 	      prefixlen - (size_t)pvpos - 2);
     }
     mm->next_pos = (void *)((char *)(mm->next_pos) + len);
-  }  /* end prefix != NULL */
+  }
 
   /* Finally, add or delete query string */
   if ((char *)(mmq->next_pos) - (char *)(mmq->curr_pos) > 1 &&
       (((char *)(mmq->curr_pos))[0] != '-' ||
        ((char *)(mmq->curr_pos))[1] != '\0')) {
-    /* length >= 1 and not just "-" (no need to call STREQ/strcmp) */
-    if (included(mm->curr_pos, FALSE, argshead) &&
-	strchr(mm->curr_pos, '?') == NULL) {
+    /* length >= 1 and not just "-" */
+    if (included(mm->curr_pos, FALSE, argshead)) {
       mmqstart = (char *)(mmq->curr_pos);
       if (*mmqstart == '?') /* assume initial ? included in %q, Apache-style */
 	mmqstart++;
@@ -663,6 +669,7 @@ choice prealias(Memman *mm, Memman *mmv, Hashentry *vhost, Memman *mmq,
       memmove(mm->next_pos, (void *)mmqstart, len);
       mm->next_pos = (void *)((char *)(mm->next_pos) + len);
     }
+    mmq->next_pos = mmq->curr_pos;
   }
   else if ((c = strchr((char *)(mm->curr_pos) + 1, '?')) != NULL) {
     *c = '\0';
@@ -671,31 +678,9 @@ choice prealias(Memman *mm, Memman *mmv, Hashentry *vhost, Memman *mmq,
     else
       mm->next_pos = c + 1;
   }
-  mmq->next_pos = mmq->curr_pos;  /* always reset mmq */
   return(OK);
 }
 
-void prealiasS(Memman *mm, Memman *mms) {
-  /* Choose between %S and %s tokens */
-  size_t len;
-
-  if ((char *)(mms->next_pos) - (char *)(mms->curr_pos) > 1 &&
-      (((char *)(mms->curr_pos))[0] != '-' ||
-       ((char *)(mms->curr_pos))[1] != '\0')) {
-    /* length >= 1 and not just "-", i.e. mms exists */
-    if ((char *)(mm->next_pos) - (char *)(mm->curr_pos) <= 1 ||
-	(((char *)(mm->curr_pos))[0] == '-' &&
-	 ((char *)(mm->curr_pos))[1] == '\0')) {
-      /* mm has the opposite property: so copy mms into mm */
-      len = strlen((char *)(mms->curr_pos));
-      mm->next_pos = mm->curr_pos;
-      memcpy(submalloc(mm, len + 1), mms->curr_pos, len + 1);
-    }
-  }
-  mms->next_pos = mms->curr_pos;  /* in any case, reset mms */
-  return;
-}
-
 void reverseonename(Hashindex *p) {
   extern Memman *xmemman;
   static char *s = NULL;
