@@ -1,4 +1,4 @@
-/***             analog 4.1             http://www.analog.cx/             ***/
+/***             analog 4.04             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -67,9 +67,9 @@ int main(int argc, char *argv[])
 	  rc = parsenextrecord(lf, fmt->form);
 	  if (rc == TRUE) {
 	    process_data(logfilep, lf, op->hash, op->arraydata, fmt->count,
-			 op->code2type, op->wanthead, op->ispagehead,
-			 op->aliashead, op->argshead, op->refargshead,
-			 &(op->dman), op->outopts.tree, op->outopts.derv,
+			 op->wanthead, op->ispagehead, op->aliashead,
+			 op->argshead, op->refargshead, &(op->dman),
+			 op->outopts.tree, op->outopts.derv,
 			 op->outopts.alltrees, op->outopts.alldervs,
 			 op->miscopts.lowmem, op->miscopts.case_insensitive,
 			 op->miscopts.usercase_insensitive,
@@ -80,7 +80,7 @@ int main(int argc, char *argv[])
 	    corrupt_pos = MAX(pos - record_start, corrupt_pos);
 	  else if (rc == NEWLOGFMT) {
 	    logfilep->format = logformat;
-	    if (correctlogfmt(logfilep, op->wanthead, op->code2type,
+	    if (correctlogfmt(logfilep, op->wanthead,
 			      &(op->dman)) == NULL) {
 	      debug('F', "Ignoring logfile %s, which contains no items "
 		    "being analysed", logfilep->name);
