@@ -1,4 +1,4 @@
-/***             analog 4.1             http://www.analog.cx/             ***/
+/***             analog 4.04             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -197,7 +197,7 @@ Hashentry *newhashentry(logical ispage) {
 void hashscore(Hashentry *ep, choice outcome, logical last7, logical ispage,
 	       timecode_t timecode, double bytes) {
 
-  if (outcome == SUCCESS) {
+  if (outcome == TRUE) {
     ep->data[REQUESTS]++;
     ep->bytes += bytes;
     ep->data[PAGES] += ispage;
@@ -205,7 +205,7 @@ void hashscore(Hashentry *ep, choice outcome, logical last7, logical ispage,
     if (last7)
       ep->last7 = TRUE;
   }
-  else if (outcome == FAILURE) {
+  else if (outcome == FALSE) {
     ep->data[FAIL]++;
     ep->data[FAILDATE] = MAX(timecode, ep->data[FAILDATE]);
   }
