@@ -1,4 +1,4 @@
-/***             analog 4.1             http://www.analog.cx/             ***/
+/***             analog 4.04             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -33,7 +33,7 @@ void confline(Options *op, char *cmd, char *arg1, char *arg2, int rc) {
   int i;
   logical done = FALSE;
 
-  strtoupper(cmd);
+  (void)strtoupper(cmd);
   if (rc >= 2 && STREQ(cmd, "SUBDOMAIN")) {   /* ugly but easy */
     sprintf(u, "%s (%s)", arg1, arg2);
     if (strchr(u, '$') != NULL || strchr(u, '*') != NULL)
@@ -133,15 +133,15 @@ void settings(Options *op, int argc, char *argv[]) {
 }
 
 Inputformatlist *correctlogfmt(Filelist *lp, Include **wanthead,
-			       choice *code2type, Dateman *dman) {
+			       Dateman *dman) {
   extern choice wantitem[];
   extern Inputfns inpfns[], pjinpfn;
   extern char *item_type[];
 
   Inputformatlist *fmt;
   Inputformat *fns;
-  logical noitem[ITEM_NUMBER], nodates, nocodes, nonames, nobytes;
   int count, i, j;
+  logical done, done2;
 
   for (count = 0, fmt = lp->format; fmt != NULL; TO_NEXT(fmt)) {
     if (!wantitem[INP_CODE] && fmt->count[INP_CODE] == 2)
@@ -178,49 +178,49 @@ Inputformatlist *correctlogfmt(Filelist *lp, Include **wanthead,
   if (count == 0)
     lp->format = NULL;  /* i.e., mark logfile to be ignored */
   else {
-    /*  logical noitem[ITEM_NUMBER], nodates, nocodes, nonames, nobytes;*/
-    for (i = 0; i < ITEM_NUMBER; i++)
-      noitem[i] = FALSE;
-    nodates = FALSE;
-    nocodes = FALSE;
-    nonames = FALSE;
-    nobytes = FALSE;
-    for (fmt = lp->format; fmt != NULL; TO_NEXT(fmt)) {
-      for (count = 0, j = 0; j < INPUT_NUMBER; j++)
-	count += (int)(fmt->count[j] == 2);
-      if (count > 0) {
-	for (i = 0; i < ITEM_NUMBER; i++) {
-	  if (fmt->count[i] == 0)
-	    noitem[i] = TRUE;
+    for (i = 0; i < ITEM_NUMBER; i++) {
+      if (wanthead[i] != NULL) {
+	for (done = FALSE, fmt = lp->format; fmt != NULL && !done;
+	     TO_NEXT(fmt)) {
+	  for (count = 0, j = 0; j < INPUT_NUMBER; j++)
+	    count += (int)(fmt->count[j] == 2);
+	  if (fmt->count[i] == 0 && count > 0) {
+	    warn('M', TRUE, "Logfile %s contains lines with no %s, which are "
+		 "being filtered", lp->name, item_type[i]);
+	    done = TRUE;
+	  }
 	}
-	if (fmt->count[INP_DATE] == 0)
-	  nodates = TRUE;
-	if (fmt->count[INP_CODE] == 0)
-	  nocodes = TRUE;
-	if (fmt->count[ITEM_FILE] == 0)
-	  nonames = TRUE;
-	if (fmt->count[INP_BYTES] == 0)
-	  nobytes = TRUE;
       }
     }
-    for (i = 0; i < ITEM_NUMBER; i++) {
-      if (wanthead[i] != NULL && noitem[i])
-	warn('M', TRUE, "Logfile %s contains lines with no %s, which are "
-	     "being filtered", lp->name, item_type[i]);
+    if (dman->from > FIRST_TIME || dman->to < LAST_TIME) {
+      for (done = FALSE, fmt = lp->format; fmt != NULL && !done;
+	   TO_NEXT(fmt)) {
+	for (count = 0, j = 0; j < INPUT_NUMBER; j++)
+	  count += (int)(fmt->count[j] == 2);
+	if (fmt->count[INP_DATE] == 0 && count > 0) {
+	  warn('M', TRUE, "Logfile %s contains lines with no dates, which are "
+	       "being filtered", lp->name, item_type[i]);
+	  done = TRUE;
+	}
+      }
+    }
+    for (done = FALSE, done2 = FALSE, fmt = lp->format; fmt != NULL;
+	 TO_NEXT(fmt)) {
+      for (count = 0, j = 0; j < INPUT_NUMBER; j++)
+	count += (int)(fmt->count[j] == 2);
+      if (fmt->count[ITEM_FILE] == 0 && count > 0 && !done) {
+	warn('M', TRUE, "Logfile %s contains lines with no file names: "
+	     "page counts may be low", lp->name);
+	done = TRUE;
+      }
+      if (fmt->count[INP_BYTES] == 0 && count > 0 && !done2) {
+	warn('M', TRUE, "Logfile %s contains lines with no bytes: byte counts "
+	     "may be low", lp->name);
+	done2 = TRUE;
+      }
     }
-    if (code2type[0] != UNSET && nocodes)
-      warn('M', TRUE, "Logfile %s contains lines with no status codes, "
-	   "which are being filtered", lp->name);
-    if ((dman->from > FIRST_TIME || dman->to < LAST_TIME) && nodates)
-      warn('M', TRUE, "Logfile %s contains lines with no dates, which are "
-	   "being filtered", lp->name);
-    if (nonames)
-      warn('M', TRUE, "Logfile %s contains lines with no file names: "
-	   "page counts may be low", lp->name);
-    if (nobytes)
-      warn('M', TRUE, "Logfile %s contains lines with no bytes: byte counts "
-	   "may be low", lp->name);
   }
+    
   return(lp->format);
 }
 
@@ -297,15 +297,15 @@ void correct(Options *op) {
     }
     op->outopts.pagewidth = op->outopts.htmlpagewidth;
   }
-  else if (op->outopts.outstyle == ASCII || op->outopts.outstyle == PLAIN) {
-    if (op->outopts.plainpagewidth == 0)
-      op->outopts.plainpagewidth = 1;
-    else if (op->outopts.plainpagewidth > MAXPAGEWIDTH) {
-      warn('C', TRUE, "PLAINPAGEWIDTH %u too large: using maximum allowed "
-	   "value of %u", op->outopts.plainpagewidth, MAXPAGEWIDTH);
-      op->outopts.plainpagewidth = MAXPAGEWIDTH;
+  else if (op->outopts.outstyle == ASCII) {
+    if (op->outopts.asciipagewidth == 0)
+      op->outopts.asciipagewidth = 1;
+    else if (op->outopts.asciipagewidth > MAXPAGEWIDTH) {
+      warn('C', TRUE, "ASCIIPAGEWIDTH %u too large: using maximum allowed "
+	   "value of %u", op->outopts.asciipagewidth, MAXPAGEWIDTH);
+      op->outopts.asciipagewidth = MAXPAGEWIDTH;
     }
-    op->outopts.pagewidth = op->outopts.plainpagewidth;
+    op->outopts.pagewidth = op->outopts.asciipagewidth;
   }
   for (i = 0, j = 0, k = 0; i < DATEREP_NUMBER; i++) {
     if (i != REP_DAYSUM && i != REP_HOURSUM) {
@@ -657,7 +657,7 @@ void correct(Options *op) {
       }
     }  /* end cachefile == none */
     for (lp = op->miscopts.logfile, templ = FALSE; lp != NULL; TO_NEXT(lp)) {
-      (void)correctlogfmt(lp, op->wanthead, op->code2type, &(op->dman));
+      (void)correctlogfmt(lp, op->wanthead, &(op->dman));
       if (op->miscopts.lowmem[ITEM_VHOST] >= 3 && lp->pvpos != UNSET) {
 	if (!templ) {
 	  warn('C', TRUE,
@@ -744,20 +744,6 @@ void finalinit(Options *op) {
   Strlist *sp;
   int i;
 
-  /* set code2type variable */
-  for (i = MIN_SC; i < SC_NUMBER; i++) {
-    if (op->code2type[i] == UNWANTED ||
-	(op->code2type[i] == UNSET && op->code2type[0] == SUCCESS))
-      op->code2type[i] = UNWANTED;
-    else if (i <= 199)
-      op->code2type[i] = INFO;
-    else if (i <= 299 || (i == 304 && op->succ304))
-      op->code2type[i] = SUCCESS;
-    else if (i <= 399)
-      op->code2type[i] = REDIRECT;
-    else
-      op->code2type[i] = FAILURE;
-  }
   /* swap aliases round */
   for (i = 0; i < ITEM_NUMBER; i++)
     reversealias(&(op->aliashead[i]));
@@ -769,9 +755,7 @@ void finalinit(Options *op) {
   if (op->outopts.domainsfile == NULL)
     configstr(&(op->outopts.domainsfile), NULL, LANGDIR"ukdom"EXTSEP"tab",
 	      NULL, -1);
-  if (!vblesonly) {  /* persists to end of function */
-    if (op->outopts.outstyle == PLAIN)
-      op->outopts.outstyle = ASCII; /* The only difference is the langfile */
+  if (!vblesonly) {
     if ((tempf = my_fopen(op->outopts.lang.file, "language file")) == NULL)
       error("Can't read language file %s", op->outopts.lang.file);
     op->outopts.dayname = (char **)xmalloc(7 * sizeof(char *));
@@ -992,30 +976,6 @@ choice strtoinfmt(Inputformat **ans, char *s, choice *count) {
     typedone[i] = FALSE;
   *ans = (Inputformat *)submalloc(xmemman, sizeof(Inputformat));
   ifp = *ans;
-  /* First a messy special case. If %s occurs but not %S, promote %s to %S */
-  for (c = s, done = FALSE; *c != '\0' && !done; c++) {
-    if (*c == '%') {
-      c++;
-      if (*c == '*')
-	c++;
-      if (*c == 'S')
-	done = TRUE;
-      c++;
-    }
-  }
-  if (!done) {
-    for (c = s; *c != '\0'; c++) {
-      if (*c == '%') {
-	c++;
-	if (*c == '*')
-	  c++;
-	if (*c == 's')
-	  *c = 'S';
-	c++;
-      }
-    }
-  }
-  /* Now the main routine */
   for (c = s; *c != '\0'; c++) {
     if (*c == '%') {
       c++;
@@ -1074,7 +1034,7 @@ choice strtoinfmt(Inputformat **ans, char *s, choice *count) {
 	    }
 	    else if (inpfns[i].fn == &parselogfmt) {
 	      c++;
-	      if (*c < '0' || *c > '6')
+	      if (*c < '0' || *c > '5')
 		return(FMT_BADBUILTIN);
 	      else
 		ifp->sep = *c;
@@ -1146,14 +1106,9 @@ choice strtoinfmt(Inputformat **ans, char *s, choice *count) {
     return(FMT_QBUTNOR);
   count[INP_BYTES] =
     2 * (choice)(typedone[INP_BYTES] && count[ITEM_FILE] == 2);
+  count[INP_CODE] = 2 * (choice)(typedone[INP_CODE] && count[ITEM_FILE] == 2);
   count[INP_PROCTIME] =
     2 * (choice)(typedone[INP_PROCTIME] && count[ITEM_FILE] == 2);
-  if (typedone[INP_CODE] && count[ITEM_FILE] == 2)
-    count[INP_CODE] = 2;
-  else if (typedone[INP_CODE])
-    count[INP_CODE] = 1;
-  else
-    count[INP_CODE] = 0;
   return(FMT_OK);
 }
 
