@@ -1,4 +1,4 @@
-/***             analog 4.1             http://www.analog.cx/             ***/
+/***             analog 4.04             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -354,8 +354,6 @@ void configoutstyle(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     longwarn(cmd, arg1, arg2, rc);
   if (strcaseeq(arg1, "HTML"))
     *s = HTML;
-  else if (strcaseeq(arg1, "PLAIN"))
-    *s = PLAIN;
   else if (strcaseeq(arg1, "ASCII"))
     *s = ASCII;
   else if (strcaseeq(arg1, "COMPUTER") || strcaseeq(arg1, "PREFORMATTED"))
@@ -436,7 +434,7 @@ void configlang(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
   else if (strcaseeq(arg1, "JAPANESE"))
     lang->code = JAPANESE;
   else if (strcaseeq(arg1, "KOREAN"))
-    lang->code = KOREAN;
+    /* lang->code = KOREAN */ v3lang = TRUE;
   else if (strcaseeq(arg1, "LATVIAN"))
     /* lang->code = LATVIAN */ v3lang = TRUE;
   else if (strcaseeq(arg1, "LITHUANIAN"))
@@ -483,38 +481,30 @@ void configlang(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
 }
 
 void selectlang(char *country, Outchoices *op) {
-  /* Select langfile and domains file with country code. If outstyle is HTML
-     or ASCII, look first for special files for those styles. */
   extern char *workspace;
   FILE *f;
 
-  if (op->outstyle == HTML || op->outstyle == ASCII) {
-    sprintf(workspace, "%s%s%c%s", LANGDIR, country,
-	    (op->outstyle == HTML)?'h':'a', EXTSEP"lng");
-  }
-  if ((op -> outstyle != HTML && op->outstyle != ASCII) ||
-      (f = FOPENR(workspace)) == NULL)
-    sprintf(workspace, "%s%s%s", LANGDIR, country, EXTSEP"lng");
+  sprintf(workspace, "%s%s%c%s%s", LANGDIR, country,
+	  (op->outstyle == HTML)?'h':'a', EXTSEP, "lng");
+  if ((f = FOPENR(workspace)) == NULL)
+    sprintf(workspace, "%s%s%s%s", LANGDIR, country, EXTSEP, "lng");
   else
     fclose(f);
   configstr(&(op->lang.file), NULL, workspace, NULL, -1);
 
   if (op->domainsfile == NULL) {
-    if (op->outstyle == HTML || op->outstyle == ASCII) {
-      sprintf(workspace, "%s%s%c%s", LANGDIR, country,
-	      (op->outstyle == HTML)?'h':'a', "dom"EXTSEP"tab");
-    }
-    if ((op->outstyle == HTML || op->outstyle == ASCII) &&
-	(f = FOPENR(workspace)) != NULL) {
+    sprintf(workspace, "%s%s%c%s%s%s", LANGDIR, country,
+	    (op->outstyle == HTML)?'h':'a', "dom", EXTSEP, "tab");
+    if ((f = FOPENR(workspace)) != NULL) {
       fclose(f);
       configstr(&(op->domainsfile), NULL, workspace, NULL, -1);
     }
     else {
-      sprintf(workspace, "%s%s%s", LANGDIR, country, "dom"EXTSEP"tab");
+      sprintf(workspace, "%s%s%s%s%s", LANGDIR, country, "dom", EXTSEP, "tab");
       if ((f = FOPENR(workspace)) != NULL) {
 	fclose(f);
 	configstr(&(op->domainsfile), NULL, workspace, NULL, -1);
-      }  /* otherwise will get set to ukdom.tab on return to finalinit() */
+      }  /* otherwise will get set on return to finalinit() */
     }
   }
 }
@@ -584,10 +574,6 @@ void configlogfmt(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     configlogfmt(opt, NULL, LOG_MS_EXTENDED1, NULL, -1);
     configlogfmt(opt, NULL, LOG_EXTENDED2, NULL, -1);
   }
-  else if (strcaseeq(arg1, "WEBSTAR-EXTENDED")) {
-    configlogfmt(opt, NULL, LOG_WEBSTAR_EXTENDED1, NULL, -1);
-    configlogfmt(opt, NULL, LOG_EXTENDED2, NULL, -1);
-  }
   else if (strcaseeq(arg1, "NETSCAPE"))
     configlogfmt(opt, NULL, LOG_NETSCAPE, NULL, -1);
   else if (strcaseeq(arg1, "BROWSER")) 
@@ -1326,7 +1312,7 @@ int aliastocount(char *s) {
 
 AliasTo *configaliasto(char *s, logical is_regex) {
   /* already checked parseable in aliastocount() */
-  /* Can prob be optimised somewhat, but with loss of any remaining clarity. */
+  /* Can probably be optimised somewhat, but with loss of remaining clarity. */
   AliasTo *ans, *atp;
   char *t, next;
 
@@ -1350,7 +1336,7 @@ AliasTo *configaliasto(char *s, logical is_regex) {
 	next = '1';
       else  /* *t == '$' */
 	next = *(++t);
-      atp->after = 2 * ((int)next - (int)(is_regex?'0':'1'));
+      atp->after = (int)next - (int)(is_regex?'0':'1');
       /* internal index of *'s is from 0; of regex brackets is from 1 */
     }
     if (*t == '\0' || *(t + 1) == '\0') {
@@ -1370,11 +1356,14 @@ void configalias(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
   Alias *ap;
   unsigned int leftstars;
   int maxrightstar;
-  char starchar;
+  char starchar = '*';
   logical is_regex = FALSE;
-  pcre *pattern = NULL;
-  char *errstr;
-  int erroffset;
+#ifndef NOREGEX
+  regex_t pattern;
+  int re_errcode;
+  size_t re_errsize;
+  char *re_errstr;
+#endif
 
   if (rc == 0) {
     shortwarn(cmd, arg1, rc);
@@ -1391,22 +1380,30 @@ void configalias(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     longwarn(cmd, arg1, arg2, rc);
 
   if (headcasematch(arg1, "REGEXP:") || headcasematch(arg1, "REGEXPI:")) {
-    if ((pattern =
-	 pcre_compile(arg1 + 7 + (arg1[6] != ':'),
-		      PCRE_DOTALL | ((arg1[6] == ':')?0:PCRE_CASELESS),
-		      (const char **)(&errstr), &erroffset, NULL)) == NULL) {
+#ifdef NOREGEX
+    badwarn(cmd, FALSE, arg1, arg2, rc);
+    warn('C', CONTINUATION,
+	 "  (no regular expressions in this version of analog)");
+    return;
+#else
+    if ((re_errcode = regcomp(&pattern, arg1 + 7 + (arg1[6] != ':'),
+			      REG_EXTENDED | ((arg1[6] == ':')?0:REG_ICASE)))
+	 != 0) {  /* compilation generated an error */
       badwarn(cmd, FALSE, arg1, arg2, rc);
-      warn('C', CONTINUATION, "  (%s in regular expression)", errstr);
+      re_errsize = regerror(re_errcode, NULL, NULL, 0);
+      /* passing pattern to regerror seems to crash */
+      re_errstr = (char *)xmalloc(re_errsize);
+      (void)regerror(re_errcode, NULL, re_errstr, re_errsize);
+      warn('C', CONTINUATION, "  (%s in regular expression)", re_errstr);
       return;
     }
     starchar = '(';
-    pcre_fullinfo(pattern, NULL, PCRE_INFO_CAPTURECOUNT, (void *)&leftstars);
+    leftstars = chrn(arg1, starchar);
     is_regex = TRUE;
+#endif
   }
-  else {
-    starchar = '*';
+  else
     leftstars = chrdistn(arg1, starchar);
-  }
   if (leftstars >= 2 && strchr(arg2, '*') != NULL) {
     badwarn(cmd, FALSE, arg1, arg2, rc);
     warn('C', CONTINUATION,
@@ -1430,9 +1427,14 @@ void configalias(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
   ap = (Alias *)xmalloc(sizeof(Alias));
   DEFAULTSTR(ap->from, arg1);   /* save string even for regex: might l.c. */
   ap->to = configaliasto(arg2, is_regex);
-  ap->isregex = is_regex;
-  if (is_regex)
-    ap->pattern = pattern;
+  ap->nmatch = maxrightstar;
+#ifndef NOREGEX
+  if (is_regex) {
+    ap->pattern = (regex_t *)xmalloc(sizeof(regex_t));
+    memcpy(ap->pattern, (void *)(&pattern), sizeof(regex_t));
+    ap->nmatch = ENCODE_NMATCH(ap->nmatch);
+  }
+#endif
   ap->next = *alias;
   *alias = ap;
 }
@@ -1515,8 +1517,11 @@ void configinex(void *opt, char *cmd, char *arg1, char *arg2, int rc,
 		logical in) {
   Include **include = (Include **)opt;
   Include *ip;
-  char *errstr;
-  int erroffset;
+#ifndef NOREGEX
+  int re_errcode;
+  size_t re_errsize;
+  char *re_errstr;
+#endif
   char *t;
 
   if (rc == 0) {
@@ -1541,16 +1546,29 @@ void configinex(void *opt, char *cmd, char *arg1, char *arg2, int rc,
   DEFAULTSTR((*include)->name, arg1);
   (*include)->next = ip;   /* save name even for regex: might l.c. */
   if (headcasematch(arg1, "REGEXP:") || headcasematch(arg1, "REGEXPI:")) {
-    if (((*include)->pattern =
-	 pcre_compile(arg1 + 7 + (arg1[6] != ':'), 
-		      PCRE_DOTALL | ((arg1[6] == ':')?0:PCRE_CASELESS),
-		      (const char **)(&errstr), &erroffset, NULL)) == NULL) {
+#ifdef NOREGEX
+    *include = ip;
+    badwarn(cmd, FALSE, arg1, arg2, rc);
+    warn('C', CONTINUATION,
+	 "  (no regular expressions in this version of analog)");
+    return;
+#else
+    (*include)->pattern = xmalloc(sizeof(regex_t));
+    if ((re_errcode = regcomp((*include)->pattern,
+			      arg1 + 7 + (arg1[6] != ':'),
+			      REG_EXTENDED | REG_NOSUB |
+			      ((arg1[6] == ':')?0:REG_ICASE))) != 0) {
       *include = ip;
       badwarn(cmd, FALSE, arg1, arg2, rc);
-      warn('C', CONTINUATION, "  (%s in regular expression)", errstr);
+      re_errsize = regerror(re_errcode, NULL, NULL, 0);
+      /* passing pattern to regerror seems to crash */
+      re_errstr = (char *)xmalloc(re_errsize);
+      (void)regerror(re_errcode, NULL, re_errstr, re_errsize);
+      warn('C', CONTINUATION, "  (%s in regular expression)", re_errstr);
       return;
     }
     (*include)->type = in?(REGEX_INC):(REGEX_EXC);
+#endif
   }
   else {
     if (strcaseeq((*include)->name, "pages"))
@@ -1594,83 +1612,3 @@ void configexcs(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     arg1[strlen(arg1) - 1] = '\0';
   configinex(opt, cmd, arg1, arg2, rc, FALSE);
 }
-
-/* for status codes */
-void configscinex(void *opt, char *cmd, char *arg1, char *arg2, int rc,
-		  logical in) {
-  choice *code2type = (choice *)opt;
-  unsigned int bottom, top;
-  char *c, *d;
-  logical f = FALSE;
-  int i;
-
-  if (rc == 0) {
-    shortwarn(cmd, arg1, rc);
-    return;
-  }
-  if (rc > 1)
-    longwarn(cmd, arg1, arg2, rc);
-
-  if (strchr(arg1, ',') != NULL) {
-    if ((c = strtok(arg1, ",")) == NULL) {
-      badwarn(cmd, TRUE, arg1, arg2, rc);
-      return;
-    }
-    for ( ; c != NULL; c = strtok((char *)NULL, ","))
-      configscinex(opt, cmd, c, NULL, 1, in);
-    return;
-  }
-
-  if (STREQ(arg1, "*")) {
-    bottom = MIN_SC;
-    top = SC_NUMBER - 1;
-  }
-  else {
-    if (*arg1 == '-') {
-      bottom = MIN_SC;
-      c = arg1 + 1;
-      if (!ISDIGIT(*c)) {
-	badwarn(cmd, TRUE, arg1, arg2, rc);
-	return;
-      }
-    }
-    else {
-      bottom = (unsigned int)strtoul(arg1, &c, 10);
-      if (*c == '-') {
-	c++;
-	f = TRUE;
-      }
-      if (bottom < MIN_SC || bottom >= SC_NUMBER ||
-	  (*c != '\0' && !ISDIGIT(*c))) {
-	badwarn(cmd, TRUE, arg1, arg2, rc);
-	return;
-      }
-    }
-    if (*c == '\0') {
-      if (f)
-	top = SC_NUMBER - 1;
-      else
-	top = bottom;
-    }
-    else {
-      top = (unsigned int)strtoul(c, &d, 10);
-      if (top < bottom || top >= SC_NUMBER || *d != '\0') {
-	badwarn(cmd, TRUE, arg1, arg2, rc);
-	return;
-      }
-    }
-  }
-
-  if (code2type[0] == UNSET)
-    code2type[0] = in?SUCCESS:UNWANTED; /* mark first in/ex: see finalinit() */
-  for (i = bottom; i <= top; i++)
-    code2type[i] = in?SUCCESS:UNWANTED; /* SUCCESS set more carefully there */
-}
-
-void configscinc(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
-  configscinex(opt, cmd, arg1, arg2, rc, TRUE);
-}
-
-void configscexc(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
-  configscinex(opt, cmd, arg1, arg2, rc, FALSE);
-}
