@@ -1,4 +1,4 @@
-/***             analog 4.1             http://www.analog.cx/             ***/
+/***             analog 4.04             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -224,7 +224,7 @@ choice getmoredata(FILE *f, char *start, size_t length) {
   return(OK);
 }
 
-choice getnextline(FILE *f, char *start, size_t used) {
+choice getnextline(FILE *f, char *start) {
   /* not very efficient: only for use during initialisation */
   char *s = start;
 
@@ -235,7 +235,7 @@ choice getnextline(FILE *f, char *start, size_t used) {
   if (*s == (char)EOF && feof(f))
     return(EOF);
   for (*(++s) = (char)getc(f); *s != '\r' && *s != '\n' && !feof(f) &&
-	 s < start + BLOCKSIZE - used - 1; *(++s) = (char)getc(f))
+	 s < start + BLOCKSIZE - 1; *(++s) = (char)getc(f))
     ;  /* read in to next new line */
   *s = '\0';
   if (s == start + BLOCKSIZE - 1)
@@ -458,13 +458,12 @@ choice parseuint2strict(FILE *f, void *arg, char c) {
   return(TRUE);
 }
 
-choice parsescode(FILE *f, void *arg, char c) {
-  /* parseuint3strict() with twiddles */
+choice parseuint3strict(FILE *f, void *arg, char c) {
   unsigned int *x = (unsigned int *)arg;
 
   *block_end = '\0';
-  if (*pos < '1' || *pos > '5') {  /* only accept codes 100 - 599, or - */
-    if (*pos == '-') {      /* see also MIN_SC, SC_NUMBER in anlghea3.h */
+  if (!ISDIGIT(*pos)) {
+    if (*pos == '-') {   /* NB uint3strict only used for status codes */
       pos++;
       *x = 200;
       return(TRUE);
@@ -893,33 +892,6 @@ choice checkchar(FILE *f, void *arg, char c) {
     return(FALSE);
 }
 
-void resolveconflicts(unsigned int n, char *delims, ...) {
-  /* Used in parselogfmt(). Munges a format header line, which is in pos, so
-     that there are no "repeated" fields. n is the number of alternatives. */
-  va_list ap;
-  char *arg, *s, *t;
-  logical found;
-  int i;
-
-  va_start(ap, delims);
-  for (i = 0, found = FALSE; i < n; i++) {
-    arg = va_arg(ap, char *);
-    for (s = strstr(pos, arg); s != NULL; s = strstr(s + 1, arg)) {
-      t = s + strlen(arg);
-      if ((s == pos || strchr(delims, *(s - 1)) != NULL) &&
-	  (*t == '\0' || strchr(delims, *t) != NULL)) {  /* true match */
-	if (found) { /* found an earlier occurrence */
-	  *s = 'X';
-	  *(s + 1) = 'X';
-	}
-	else  /* no earlier occurrence: leave this one alone */
-	  found = TRUE;
-      }
-    }
-  }
-  va_end(ap);
-}
-
 choice parselogfmt(FILE *f, void *arg, char c) {
   extern Inputformatlist *logformat;
   extern char *workspace;  /* assume large enough, as usual */
@@ -1010,22 +982,11 @@ choice parselogfmt(FILE *f, void *arg, char c) {
       configlogfmt((void *)&logformat, NULL, "BROWSER", NULL, -1);
     }
     else if (*pos == '#') {
-      /* look at first the two lines to determine vendor, although we expect
-	 Microsoft string on first line, and WebSTAR on second. */
-      for (e = d + 1; *e == '\n' || *e == '\r'; e++)
-	;
-      if (headmatch(pos + 1,
-		    "Software: Microsoft Internet Information Server") ||
-	  headmatch(e, "#Software: Microsoft Internet Information Server")) {
-	debug('F',
-	      "  Detect that it's in Microsoft's version of extended format");
+      if (*(pos + 11) == 'M' && *(pos + 21) == 'I' && *(pos + 30) == 'I' &&
+	  *(pos + 42) == 'S') {
+	debug('F', "  Detect that it's in Microsoft's extended format");
 	configlogfmt((void *)&logformat, NULL, "MS-EXTENDED", NULL, -1);
       }
-      else if (headmatch(e, "#Software: WebSTAR") ||
-	       headmatch(pos + 1, "Software: WebSTAR")) {
-	debug('F', "  Detect that it's in extended format (WebSTAR server)");
-	configlogfmt((void *)&logformat, NULL, "WEBSTAR-EXTENDED", NULL, -1);
-      }
       else {
 	debug('F', "  Detect that it's in W3 extended format");
 	configlogfmt((void *)&logformat, NULL, "EXTENDED", NULL, -1);
@@ -1060,60 +1021,48 @@ choice parselogfmt(FILE *f, void *arg, char c) {
     break;
   case '2':  /* WebSTAR format */
     /* pos is already start of format proper */
-    strtoupper(pos);
-    resolveconflicts(5, " \t", "SC-STATUS", "RESULT_CODE", "STATUS",
-		     "CS-STATUS",  "RESULT");
-    resolveconflicts(3, " \t", "CS-URI-STEM", "CS-URI", "URL");
-    resolveconflicts(2, " \t", "BYTES", "BYTES_SENT");
-    resolveconflicts(4, " \t", "HOSTNAME", "C-DNS", "CS-HOST", "CS-DNS");
-    resolveconflicts(2, " \t", "C-IP", "CS-IP");
-    resolveconflicts(2, " \t", "REFERER", "CS(REFERER)");
-    resolveconflicts(2, " \t", "AGENT", "CS(USER-AGENT)");
-    resolveconflicts(4, " \t", "HOSTFIELD", "CS(HOST)", "HOST", "CS-SIP");
-    resolveconflicts(2, " \t", "SEARCH_ARGS", "CS-URI-QUERY");
     workspace[0] = '\0';
     pos = strtok(pos, " \t");
     while (pos != NULL) {
       if (!IS_EMPTY_STRING(workspace))
 	strcat(workspace, "\t");
-      if (STREQ(pos, "COMMON_LOG_FORMAT"))
+      if (strcaseeq(pos, "COMMON_LOG_FORMAT"))
 	strcpy(workspace, "COMMON");
-      else if (STREQ(pos, "DATE"))
+      else if (strcaseeq(pos, "DATE"))
 	strcat(workspace, "%m/%d/%y");
-      else if (STREQ(pos, "TIME"))
+      else if (strcaseeq(pos, "TIME"))
 	strcat(workspace, "%W%h:%n:%j");
-      else if (STREQ(pos, "RESULT"))
+      else if (strcaseeq(pos, "RESULT"))
 	strcat(workspace, "%C");
-      else if (STREQ(pos, "SC-STATUS") || STREQ(pos, "CS-STATUS") ||
-	       STREQ(pos, "RESULT_CODE") || STREQ(pos, "STATUS"))
+      else if (strcaseeq(pos, "SC-STATUS") || strcaseeq(pos, "CS-STATUS") ||
+	       strcaseeq(pos, "RESULT_CODE") || strcaseeq(pos, "STATUS"))
 	strcat(workspace, "%c");
-      else if (STREQ(pos, "URL") || STREQ(pos, "CS-URI-STEM") ||
-	       STREQ(pos, "CS-URI"))
+      else if (strcaseeq(pos, "URL") || strcaseeq(pos, "CS-URI-STEM") ||
+	       strcaseeq(pos, "CS-URI"))
 	strcat(workspace, "%r");
-      else if (STREQ(pos, "BYTES") || STREQ(pos, "BYTES_SENT"))
+      else if (strcaseeq(pos, "BYTES") || strcaseeq(pos, "BYTES_SENT"))
 	strcat(workspace, "%b");
-      else if (STREQ(pos, "HOSTNAME") || STREQ(pos, "CS-HOST") ||
-	       STREQ(pos, "C-DNS") || STREQ(pos, "CS-DNS"))
+      else if (strcaseeq(pos, "HOSTNAME") || strcaseeq(pos, "CS-HOST") ||
+	       strcaseeq(pos, "CS-IP") || strcaseeq(pos, "C-IP") ||
+	       strcaseeq(pos, "C-DNS") || strcaseeq(pos, "CS-DNS"))
 	strcat(workspace, "%S");
-      else if (STREQ(pos, "CS-IP") || STREQ(pos, "C-IP"))
-	strcat(workspace, "%s");
-      else if (STREQ(pos, "REFERER"))
+      else if (strcaseeq(pos, "REFERER"))
 	strcat(workspace, "%f");
-      else if (STREQ(pos, "CS(REFERER)"))
+      else if (strcaseeq(pos, "CS(REFERER)"))
 	strcat(workspace, "\"%f\"");
-      else if (STREQ(pos, "AGENT"))
+      else if (strcaseeq(pos, "AGENT"))
 	strcat(workspace, "%B");
-      else if (STREQ(pos, "CS(USER-AGENT)"))
+      else if (strcaseeq(pos, "CS(USER-AGENT)"))
 	strcat(workspace, "\"%B\"");
-      else if (STREQ(pos, "CS(HOST)") || STREQ(pos, "HOSTFIELD"))
+      else if (strcaseeq(pos, "CS(HOST)") || strcaseeq(pos, "HOSTFIELD"))
 	strcat(workspace, "\"%v\"");
-      else if (STREQ(pos, "HOST") || STREQ(pos, "CS-SIP"))
+      else if (strcaseeq(pos, "HOST"))
 	strcat(workspace, "%v");
-      else if (STREQ(pos, "SEARCH_ARGS") || STREQ(pos, "CS-URI-QUERY"))
+      else if (strcaseeq(pos, "SEARCH_ARGS") || strcaseeq(pos, "CS-URI-QUERY"))
 	strcat(workspace, "%q");
-      else if (STREQ(pos, "USER"))
+      else if (strcaseeq(pos, "USER"))
 	strcat(workspace, "%u");
-      else if (STREQ(pos, "TRANSFER_TIME"))
+      else if (strcaseeq(pos, "TRANSFER_TIME"))
 	strcat(workspace, "%t");
       else
 	strcat(workspace, "%j");
@@ -1126,76 +1075,53 @@ choice parselogfmt(FILE *f, void *arg, char c) {
     break;
   case '3':  /* W3 extended format */
   case '5':  /* Microsoft's attempt at same */
-  case '6':  /* WebSTAR's (much closer :-) attempt at same */
-    strtoupper(pos);
-    resolveconflicts(2, " \t", "BYTES", "SC-BYTES");
-    resolveconflicts(2, " \t", "C-IP", "CS-IP");
-    if (c == '6') {  /* WebSTAR */
-      resolveconflicts(3, " \t", "C-DNS", "CS-DNS", "CS-HOST");
-      resolveconflicts(6, " \t", "CS(HOST)", "S-DNS", "S-IP",
-		       "CS-SIP", "S-SITENAME", "S-COMPUTERNAME");
-    }
-    else {
-      resolveconflicts(2, " \t", "C-DNS", "CS-DNS");
-      resolveconflicts(7, " \t", "CS(HOST)", "CS-HOST", "S-DNS", "S-IP",
-		       "S-SITENAME", "S-COMPUTERNAME", "CS-SIP");
-    }
-    resolveconflicts(2, " \t", "CS-URI-STEM", "CS-URI");
-    resolveconflicts(3, " \t", "CS-USERNAME", "CS(FROM)", "CS(COOKIE)");
     workspace[0] = '\0';
     pos = strtok(pos, " \t");
     while (pos != NULL) {
       if (!IS_EMPTY_STRING(workspace))
 	strcat(workspace, "%w");
-      if (STREQ(pos, "DATE"))
+      if (strcaseeq(pos, "DATE"))
 	strcat(workspace, "%Y-%m-%d");
-      else if (STREQ(pos, "TIME"))
+      else if (strcaseeq(pos, "TIME"))
 	strcat(workspace, "%h:%n:%j");
-      else if (STREQ(pos, "BYTES") || STREQ(pos, "SC-BYTES"))
+      else if (strcaseeq(pos, "BYTES") || strcaseeq(pos, "SC-BYTES"))
 	strcat(workspace, "%b");
-      else if (STREQ(pos, "SC-STATUS"))
+      else if (strcaseeq(pos, "SC-STATUS"))
 	strcat(workspace, "%c");
-      else if (STREQ(pos, "C-DNS") || STREQ(pos, "CS-DNS"))
+      else if (strcaseeq(pos, "CS-IP") || strcaseeq(pos, "C-IP") ||
+	       strcaseeq(pos, "C-DNS") || strcaseeq(pos, "CS-DNS"))
 	strcat(workspace, "%S");
-      else if (STREQ(pos, "CS-IP") || STREQ(pos, "C-IP"))
-	strcat(workspace, "%s");
-      else if (STREQ(pos, "CS-URI-STEM") || STREQ(pos, "CS-URI"))
+      else if (strcaseeq(pos, "CS-URI-STEM") || strcaseeq(pos, "CS-URI"))
 	strcat(workspace, "%r");
-      else if (STREQ(pos, "CS(REFERER)")) {
-	if (c == '5')  /* Microsoft */
-	  strcat(workspace, "%f");
-	else
+      else if (strcaseeq(pos, "CS(REFERER)")) {
+	if (c == '3')  /* W3 */
 	  strcat(workspace, "\"%f\"");
+	else         /* M$ */
+	  strcat(workspace, "%f");
       }
-      else if (STREQ(pos, "CS(USER-AGENT)")) {
-	if (c == '5')  /* Microsoft */
-	  strcat(workspace, "%A");
-	else
+      else if (strcaseeq(pos, "CS(USER-AGENT)")) {
+	if (c == '3')
 	  strcat(workspace, "\"%B\"");
-      }
-      else if (STREQ(pos, "CS-HOST")) {
-	if (c == '6')  /* WebSTAR */
-	  strcat(workspace, "%S");
 	else
-	  strcat(workspace, "%v");
+	  strcat(workspace, "%A");
       }
-      else if (STREQ(pos, "CS(HOST)"))
+      else if (strcaseeq(pos, "CS(HOST)"))
 	strcat(workspace, "\"%v\"");
-      else if (STREQ(pos, "S-IP") ||
-	       STREQ(pos, "S-DNS") || STREQ(pos, "CS-SIP") ||
-	       STREQ(pos, "S-SITENAME") || STREQ(pos, "S-COMPUTERNAME"))
+      else if (strcaseeq(pos, "CS-HOST") || strcaseeq(pos, "S-IP") ||
+	       strcaseeq(pos, "S-DNS"))
 	strcat(workspace, "%v");
-      else if (STREQ(pos, "CS-URI-QUERY"))
+      else if (strcaseeq(pos, "CS-URI-QUERY"))
 	strcat(workspace, "%q");
-      else if (STREQ(pos, "CS(FROM)"))
+      else if (strcaseeq(pos, "CS(FROM)"))
 	strcat(workspace, "\"%u\"");
-      else if (STREQ(pos, "CS-USERNAME") || STREQ(pos, "CS(COOKIE)"))
+      else if (strcaseeq(pos, "CS-USERNAME"))
+	/* would like to include CS(COOKIE) here, but can't have two %u's */
 	strcat(workspace, "%u");
-      else if (STREQ(pos, "TIME-TAKEN")) {
-	if (c == '5')  /* Microsoft */
-	  strcat(workspace, "%T");
-	else
+      else if (strcaseeq(pos, "TIME-TAKEN")) {
+	if (c == '3')
 	  strcat(workspace, "%t");
+	else
+	  strcat(workspace, "%T");
       }
       else
 	strcat(workspace, "%j");
@@ -1203,22 +1129,13 @@ choice parselogfmt(FILE *f, void *arg, char c) {
     }
     if (c == '3')
       configlogfmt((void *)&logformat, NULL, "EXTENDED", NULL, -1);
-    else if (c == '5')
+    else
       configlogfmt((void *)&logformat, NULL, "MS-EXTENDED", NULL, -1);
-    else /* c == '6' */
-      configlogfmt((void *)&logformat, NULL, "WEBSTAR-EXTENDED", NULL, -1);
     configlogfmt((void *)&logformat, NULL, workspace, NULL, -3);
     pos = d + 1;
     (void)parsenewline(f, NULL, '\0');
     break;
   case '4':  /* Netscape format */
-    resolveconflicts(2, "%", "Req->vars.auth-user", "Req->vars.pauth-user");
-    resolveconflicts(2, "%", "Req->reqpb.clf-request",
-		     "Req->reqpb.proxy-request");
-    resolveconflicts(3, "%", "Req->srvhdrs.content-length",
-		     "Req->headers.content-length", "Req->vars.p2c-cl");
-    resolveconflicts(2, "%", "Req->vars.xfer-time",
-		     "Req->vars.xfer-time-total");
     workspace[0] = '\0';
     while (*pos != '\0') {
       if (*pos != '%') {
@@ -1287,7 +1204,7 @@ choice parsenextrecord(FILE *f, Inputformat *format) {
     if (pos > block_bell) {
       if (record_start != block_start)
 	shunt_data(f);
-      if (pos == block_end && block_end - block_start < BLOCKSIZE)
+      if (pos == block_end)
 	return(EOF);
     }
 
@@ -1369,20 +1286,15 @@ int parseconfline(char *s, char **cmd, char **arg1, char **arg2) {
 
 int nextconfline(FILE *f, char **cmd, char **arg1, char **arg2) {
   /* if 255 increased, so must u[] be in confline() */
-  size_t l;
   int rc;
 
   *cmd = NULL;
   *arg1 = NULL;
   *arg2 = NULL;
   while (TRUE) {
-    if (getnextline(f, block_start, 0) == EOF)
+    if (getnextline(f, block_start) == EOF)
       return(EOF);
-    while ((l = strlen(block_start)) > 0 && *(block_start + l - 1) == '\\') {
-      if (getnextline(f, block_start + l - 1, l - 1) == EOF)
-	return(EOF);
-    }
-    if (l >= 255) {
+    if (strlen(block_start) >= 255) {
       *(block_start + 70) = '\0';
       warn('C', TRUE, "Ignoring long configuration line starting\n%s",
 	   block_start);
@@ -1395,7 +1307,7 @@ int nextconfline(FILE *f, char **cmd, char **arg1, char **arg2) {
 char *nextlngstr(FILE *f, char *name, logical want) {
 
   while (TRUE) {
-    if (getnextline(f, block_start, 0) == EOF) {  /* EOF reached */
+    if (getnextline(f, block_start) == EOF) {  /* EOF reached */
       if (want)
 	error("language file %s too short", name);
       else
@@ -1417,7 +1329,7 @@ choice nextdnsline(FILE *f, timecode_t *timec, char **name, char **alias) {
 
   *name = NULL;
   *alias = NULL;
-  if (getnextline(f, block_start, 0) == EOF)
+  if (getnextline(f, block_start) == EOF)
     return(EOF);
   if (strlen(block_start) >= 255) {
     *(block_start + 70) = '\0';
@@ -1442,7 +1354,7 @@ void process_domainsfile(FILE *f, Options *op) {
   char *s, *t, *c, *u, v[256];
 
   while (TRUE) {
-    if (getnextline(f, block_start, 0) == EOF)
+    if (getnextline(f, block_start) == EOF)
       return;
     if (*block_start == '#')
       ;  /* ignore comment line */
