@@ -1,4 +1,4 @@
-/***             analog 4.1             http://www.analog.cx/             ***/
+/***             analog 4.04             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -180,7 +180,7 @@ void genrep(FILE *outf, choice rep, choice outstyle, logical multibyte,
       width[COL_TITLE] = (ISDIGIT(ip->name[0]) &&
 			  ISDIGIT(ip->name[strlen(ip->name) - 1]))?0:tw;
     printcols(outf, rep, cols, outstyle, multibyte, ip->own->data[requests],
-	      ip->own->data[PAGES], ip->own->bytes, (long)(++goodn), 0,
+	      ip->own->data[PAGES], ip->own->bytes, (long)(++goodn),
 	      totr, totp, totb, width, bmult, '\0', unit, '\0', '\0',
 	      repsepchar, decpt, compsep,
 	      (logical)(rep == REP_SIZE || rep == REP_PROCTIME), FALSE,
@@ -192,7 +192,7 @@ void genrep(FILE *outf, choice rep, choice outstyle, logical multibyte,
   }
   if (badn > 0) {
     printcols(outf, rep, cols, outstyle, multibyte, badp->data[requests],
-	      badp->data[PAGES], badp->bytes, -1, 0, totr, totp, totb, width,
+	      badp->data[PAGES], badp->bytes, -1, totr, totp, totb, width,
 	      bmult, '\0', unit, '\0', '\0', repsepchar, decpt, compsep,
 	      (logical)(rep == REP_SIZE || rep == REP_PROCTIME), FALSE, NULL,
 	      html, NULL, FALSE, 0, NULL, NULL, NULL, lngstr[genrepdate_],
@@ -326,8 +326,8 @@ void subdayrep(FILE *outf, choice rep, Daysdata *firstdp, Daysdata *lastdp,
     else if (rep == REP_FIVE)
       newmin = (min + 5) % 60;
     printcols(outf, rep, cols, outstyle, FALSE, trp->reqs, trp->pages,
-	      trp->bytes, -1, -1, totr, totp, totb, width, bmult, graphby,
-	      unit, barstyle, markchar, repsepchar, decpt, compsep, TRUE, TRUE,
+	      trp->bytes, -1, totr, totp, totb, width, bmult, graphby, unit,
+	      barstyle, markchar, repsepchar, decpt, compsep, TRUE, TRUE,
 	      imagedir, html, "", FALSE, 0, NULL, NULL, NULL, datefmt, NULL,
 	      trp->date, (unsigned int)hr, (unsigned int)min,
 	      (unsigned int)((newmin == 0)?(hr + 1):(hr)),
@@ -461,8 +461,8 @@ void superdayrep(FILE *outf, choice rep, Daysdata *firstdp, Daysdata *lastdp,
       first = FALSE;
     }
     printcols(outf, rep, cols, outstyle, FALSE, trp->reqs, trp->pages,
-	      trp->bytes, -1, -1, totr, totp, totb, width, bmult, graphby,
-	      unit, barstyle, markchar, repsepchar, decpt, compsep, TRUE, TRUE,
+	      trp->bytes, -1, totr, totp, totb, width, bmult, graphby, unit,
+	      barstyle, markchar, repsepchar, decpt, compsep, TRUE, TRUE,
 	      imagedir, html, "", FALSE, 0, NULL, NULL, NULL, datefmt, NULL,
 	      trp->date, 0, 0, 0, 0, monthname, NULL, monthlen, 0,
 	      plainmonthlen, 0);
@@ -526,8 +526,8 @@ void daysum(FILE *outf, Daysdata *firstdp, datecode_t firstdate,
   for (i = 0; i < 7; i++) {
     weekday = (weekbeginson + i) % 7;
     printcols(outf, REP_DAYSUM, cols, outstyle, FALSE, reqs[weekday],
-	      pages[weekday], bys[weekday], -1, -1, totr, totp, totb, width,
-	      bmult, graphby, unit,
+	      pages[weekday],
+	      bys[weekday], -1, totr, totp, totb, width, bmult, graphby, unit,
 	      barstyle, markchar, repsepchar, decpt, compsep, TRUE, TRUE,
 	      imagedir, html, dayname[weekday], FALSE, 0, NULL, NULL, NULL, "",
 	      "", 0, 0, 0, 0, 0, NULL, NULL, 0, 0, 0, 0);
@@ -579,7 +579,7 @@ void hoursum(FILE *outf, Daysdata *firstdp, Daysdata *lastdp, choice outstyle,
   for (i = 0; i < 24; i++) {
     sprintf(temps, "%d", i);
     printcols(outf, REP_HOURSUM, cols, outstyle, FALSE, reqs[i], pages[i],
-	      bys[i], -1, -1, totr, totp, totb, width, bmult, graphby, unit,
+	      bys[i], -1, totr, totp, totb, width, bmult, graphby, unit,
 	      barstyle, markchar, repsepchar, decpt, compsep, TRUE, TRUE,
 	      imagedir, html, temps, FALSE, 0, NULL, NULL, NULL, "", "", 0, 0,
 	      0, 0, 0, NULL, NULL, 0, 0, 0, 0);
@@ -618,9 +618,9 @@ void printtree(FILE *outf, choice rep, choice outstyle, logical multibyte,
       }
       printcols(outf, rep, cols, outstyle, multibyte, p->own->data[requests],
 		p->own->data[PAGES], p->own->bytes,
-		(level == 0)?((long)(++goodn)):(-1), (int)level + 1, totr,
-		totp, totb, width, bmult, '\0', unit, '\0', '\0', repsepchar,
-		decpt, compsep, FALSE, FALSE, NULL, html, name,
+		(level == 0)?((long)(++goodn)):(-1), totr, totp, totb,
+		width, bmult, '\0', unit, '\0', '\0', repsepchar, decpt,
+		compsep, FALSE, FALSE, NULL, html, name,
 		(logical)(p->own->ispage % 16), 2 * level, aliashead,
 		linkhead, baseurl, lngstr[genrepdate_], lngstr[genreptime_],
 		p->own->data[date] / 1440, (p->own->data[date] % 1440) / 60,
@@ -638,7 +638,7 @@ void printtree(FILE *outf, choice rep, choice outstyle, logical multibyte,
   }
   if (badn > 0 && level == 0) {
     printcols(outf, rep, cols, outstyle, multibyte, badp->data[requests],
-	      badp->data[PAGES], badp->bytes, -1, 1, totr, totp, totb, width,
+	      badp->data[PAGES], badp->bytes, -1, totr, totp, totb, width,
 	      bmult, '\0', unit, '\0', '\0', repsepchar, decpt, compsep, FALSE,
 	      FALSE, NULL, html, NULL, FALSE, 0, NULL, NULL, NULL,
 	      lngstr[genrepdate_], lngstr[genreptime_],
@@ -875,8 +875,8 @@ void arrayrep(FILE *outf, choice rep, choice outstyle, logical multibyte,
     if (i == lasti)
       done = TRUE;
   }
-  genrep(outf, rep, outstyle, (logical)((rep == REP_CODE)?multibyte:FALSE),
-	 &good, &bad, NULL, NULL, REQUESTS, SUCCDATE,
+  genrep(outf, rep, outstyle, (rep == REP_CODE)?multibyte:FALSE, &good, &bad,
+	 NULL, NULL, REQUESTS, SUCCDATE,
 	 floor, sortby, FALSE, pagewidth, sepchar, repsepchar, decpt, compsep,
 	 rawbytes, cols, colhead, colheadp, gens, genp, gender, html,
 	 firsttime, monthname, dayname, monthlen, daylen, plainmonthlen,
