@@ -1,4 +1,4 @@
-/***             analog 4.1             http://www.analog.cx/             ***/
+/***             analog 4.04             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -28,8 +28,7 @@ void pagetop(FILE *outf, Outchoices *od, Dateman *dman) {
 	    "content=\"text/html; charset=%s\">\n", od->lngstr[charset_]);
     if (od->norobots)
       fputs("<meta name=\"robots\" content=\"noindex,nofollow\">\n", outf);
-    fprintf(outf, "<meta name=\"GENERATOR\" content=\"analog %s\">\n",
-	    VERSION);
+    fprintf(outf, "<meta name=\"GENERATOR\" content=\"analog%s\">\n", VERSION);
     fprintf(outf, "<title>%s ", od->lngstr[webstatsfor_]);
     htmlfprintf(outf, od->outstyle, od->multibyte, od->hostname, &(od->html),
 		TRUE);
@@ -75,7 +74,7 @@ void pagetop(FILE *outf, Outchoices *od, Dateman *dman) {
     include_file(outf, od->outstyle, od->headerfile, 'h', od->pagewidth,
 		 &(od->html));
   if (od->outstyle == COMPUTER) {
-    fprintf(outf, "x%sVE%sanalog %s\n", od->compsep, od->compsep, VNUMBER);
+    fprintf(outf, "x%sVE%sanalog%s\n", od->compsep, od->compsep, VERSION);
     fprintf(outf, "x%sHN%s%s\n", od->compsep, od->compsep, od->hostname);
     if (!STREQ(od->hosturl, "none"))
       fprintf(outf, "x%sHU%s%s\n", od->compsep, od->compsep, od->hosturl);
@@ -141,10 +140,10 @@ void pagebot(FILE *outf, Outchoices *od) {
   long secs;
 
   if (od->outstyle == HTML)
-    fprintf(outf, "<i>%s <a HREF=\"%s\">analog %s</a>.\n", od->lngstr[credit_],
-	    ANALOGURL, VNUMBER);
+    fprintf(outf, "<i>%s <a HREF=\"%s\">analog%s</a>.\n", od->lngstr[credit_],
+	    ANALOGURL, VERSION);
   else if (od->outstyle == ASCII)
-    fprintf(outf, "%s analog %s.\n", od->lngstr[credit_], VNUMBER);
+    fprintf(outf, "%s analog%s.\n", od->lngstr[credit_], VERSION);
   if (od->runtime && (od->outstyle == HTML || od->outstyle == ASCII)) {
     if (od->outstyle == HTML)
       fprintf(outf, "<br><b>%s:</b> ", od->lngstr[runtime_]);
@@ -179,13 +178,12 @@ void pagebot(FILE *outf, Outchoices *od) {
     fputs("alt=\"HTML 2.0 Conformant!\"></a>\n", outf);
   }
   if (od->outstyle == HTML)
-    fputs("</body>\n</html>\n", outf);
+    fputs("\n</body>\n</html>\n", outf);
 }
 
 /* Print "goto"s. Assume outstyle == HTML and want-gotos already tested. */
 void gotos(FILE *outf, int code, logical *repq, char **lngstr,
 	   choice *reporder) {
-  extern char *anchorname[];
   int i;
 
   fprintf(outf, "<p>(<b>%s</b>", lngstr[goto_]);
@@ -194,8 +192,8 @@ void gotos(FILE *outf, int code, logical *repq, char **lngstr,
     if (reporder[i] == code)
       fprintf(outf, "%s %s", lngstr[colon_], lngstr[rep2lng[reporder[i]]]);
     else if (repq[reporder[i]])
-      fprintf(outf, "%s <a HREF=\"#%s\">%s</a>", lngstr[colon_],
-	      anchorname[reporder[i]], lngstr[rep2lng[reporder[i]]]);
+      fprintf(outf, "%s <a HREF=\"#Rep%d\">%s</a>", lngstr[colon_],
+	      reporder[i], lngstr[rep2lng[reporder[i]]]);
   }
   fputs(")\n", outf);
 }
@@ -203,11 +201,9 @@ void gotos(FILE *outf, int code, logical *repq, char **lngstr,
 void report_title(FILE *outf, char *name, int code, choice gotoq,
 		  logical *repq, char **lngstr, choice *reporder,
 		  choice outstyle) {
-  extern char *anchorname[];
 
   if (outstyle == HTML) {
-    fprintf(outf, "<h2><a NAME=\"%s\">%s</a></h2>\n", anchorname[code],
-	    name);
+    fprintf(outf, "<h2><a NAME=\"Rep%d\">%s</a></h2>\n", code, name);
     if (gotoq == TRUE)
       gotos(outf, code, repq, lngstr, reporder);
   }
@@ -1090,8 +1086,8 @@ void colheads(FILE *outf, choice *cols, choice outstyle, unsigned int width[],
 }
 
 void printcols(FILE *outf, choice rep, choice *cols, choice outstyle,
-	       logical multibyte, unsigned long reqs, unsigned long pages,
-	       double bys, long index, int level,
+	       logical multibyte,
+	       unsigned long reqs, unsigned long pages, double bys, long index,
 	       unsigned long totr, unsigned long totp, double totb,
 	       unsigned int width[], unsigned int bmult, char graphby,
 	       double unit, char barstyle, char markchar, char repsepchar,
@@ -1105,8 +1101,6 @@ void printcols(FILE *outf, choice rep, choice *cols, choice outstyle,
 	       unsigned int daylen, unsigned int plainmonthlen,
 	       unsigned int plaindaylen) {
   /* NB multibyte only used if name1st == FALSE; so not needed for time reps */
-  /* 'level' is -1 for time reports, 0 for other non-hierarchical reports
-     (although both are currently ignored). */
   extern char *workspace;   /* see top of alias.c */
   extern char repcodes[];
   static char *datestr = NULL;
@@ -1115,8 +1109,6 @@ void printcols(FILE *outf, choice rep, choice *cols, choice outstyle,
 
   if (outstyle == COMPUTER) {
     fprintf(outf, "%c%s", repcodes[rep], compsep);
-    if (level >= 1)
-      putc('l', outf);
     for (c = 0; cols[c] != COL_NUMBER; c++) {
       switch(cols[c]) {
       case COL_REQS:
@@ -1163,8 +1155,6 @@ void printcols(FILE *outf, choice rep, choice *cols, choice outstyle,
     fprintf(outf, "%s: ", name);
   }
 
-  if (outstyle == COMPUTER && level >= 1)
-    fprintf(outf, "%d%s", level, compsep);
   for (c = 0; cols[c] != COL_NUMBER; c++) {
     switch(cols[c]) {
     case COL_REQS:
