@@ -1,4 +1,4 @@
-/***             analog 4.1             http://www.analog.cx/             ***/
+/***             analog 4.04             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -9,8 +9,7 @@
 #include "anlghea3.h"
 
 void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
-		  Arraydata **arraydata, choice *count, choice *code2type,
-		  Include **wanthead,
+		  Arraydata **arraydata, choice *count, Include **wanthead,
 		  Include *ispagehead, Alias **aliashead, Include *argshead,
 		  Include *refargshead, Dateman *dman, Tree **tree,
 		  Derv **derv, choice *alltrees, choice *alldervs,
@@ -22,7 +21,7 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
   extern unsigned long unixtime, proctime;
   extern char am;
   extern double bytes;
-  extern Memman mm[], mmq, mms, *amemman;
+  extern Memman mm[], mmq, *amemman;
   extern choice *rep2type;
   extern Hashentry *unwanted_entry, *blank_entry;
   extern Hashindex *dummy_item;
@@ -32,7 +31,7 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
   logical wanttree[ITEM_NUMBER];
   logical isitpage, last7;
   choice ispage = UNSET;
-  choice wanted = TRUE, rc, outcome;
+  choice wanted = TRUE, outcome;
   timecode_t timecode = FIRST_TIME;
   char *name, *namestart, *nameend;
   size_t len;
@@ -40,21 +39,15 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
 
   /*** check whether this line is wanted ***/
 
-  if (count[INP_CODE] != 0) {
-    if (code == IGNORE_CODE) {
-      for (j = 0; j < ITEM_NUMBER; j++) {   /* reset strings */
-	if (count[j] != 0)
-	  mm[j].next_pos = mm[j].curr_pos;
-      }
-      mmq.next_pos = mmq.curr_pos;
-      mms.next_pos = mms.curr_pos;
-      logfilep->data[LOGDATA_UNKNOWN]++;
-      return;
+  if (code == IGNORE_CODE && count[INP_CODE] != 0) {
+    for (j = 0; j < ITEM_NUMBER; j++) {   /* reset strings */
+      if (count[j] != 0)
+	mm[j].next_pos = mm[j].curr_pos;
     }
-    else if (code2type[code] == UNWANTED)
-      wanted = FALSE;
+    logfilep->data[LOGDATA_UNKNOWN]++;
+    return;
   }
-  if (wanted && count[INP_DATE] > 0) {
+  else if (count[INP_DATE] > 0) {
     if (count[INP_UNIXTIME])
       wanted = wantunixtime(&timecode, dman, unixtime, logfilep->tz);
     else {
@@ -83,13 +76,9 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
 	if (count[j] != 0)                 /* NB i is now (unwanted i) + 1 */
 	  mm[j].next_pos = mm[j].curr_pos;
       }
-      mmq.next_pos = mmq.curr_pos;
-      mms.next_pos = mms.curr_pos;
       logfilep->data[LOGDATA_UNWANTED]++;
       return;
     }
-    if (i == ITEM_HOST)
-      prealiasS(&(mm[ITEM_HOST]), &mms);
     name = (char *)(mm[i].curr_pos);
     if (count[i] == 0 || IS_EMPTY_STRING(name) ||
 	(name[0] == '-' && name[1] == '\0')) {
@@ -126,20 +115,20 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
       }
 
       else if (lowmem[i] == 1) {
-	if ((rc = do_alias(name, amemman, aliashead[i], dirsuffix,
-			   dirsufflength, usercase_insensitive, 0, i))
+	if ((outcome = do_alias(name, amemman, aliashead[i], dirsuffix,
+				dirsufflength, usercase_insensitive, 0, i))
 	    == FALSE) {
 	  item[i] = hashfind(&mm[i], &(hash[i]), wanthead[i], UNSET,
 			     ispagehead, NULL, dirsuffix, dirsufflength,
 			     usercase_insensitive, 0, i, TRUE)->own;
 	}
-	else if (rc == TRUE) {
+	else if (outcome == TRUE) {
 	  mm[i].next_pos = mm[i].curr_pos;  /* don't save string */
 	  item[i] = hashfind(amemman, &(hash[i]), wanthead[i], UNSET,
 			     ispagehead, NULL, dirsuffix, dirsufflength,
 			     usercase_insensitive, 0, i, TRUE)->own;
 	}
-	else { /* rc == ERR */
+	else { /* outcome == ERR */
 	  mm[i].next_pos = mm[i].curr_pos;
 	  item[i] = blank_entry;
 	}
@@ -147,16 +136,17 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
       }
 
       else { /* lowmem[i] >= 2 */
-	if ((rc = do_alias(name, amemman, aliashead[i], dirsuffix,
-			   dirsufflength, usercase_insensitive, 0, i))
+	if ((outcome = do_alias(name, amemman, aliashead[i], dirsuffix,
+				dirsufflength, usercase_insensitive, 0, i))
 	    == TRUE) {
 	  mm[i].next_pos = mm[i].curr_pos;  /* don't save old string */
 	  len = strlen((char *)(amemman->curr_pos));
-	  memcpy(submalloc(&(mm[i]), len + 1), amemman->curr_pos, len + 1);
+	  memcpy(submalloc(&(mm[i]), len + 1), (void *)(amemman->curr_pos),
+		 len + 1);
 	  name = (char *)(mm[i].curr_pos); /* which might have changed */
 	  amemman->next_pos = amemman->curr_pos;
 	}
-	if (rc == ERR) {
+	if (outcome == ERR) {
 	  item[i] = blank_entry;
 	  mm[i].next_pos = mm[i].curr_pos;
 	  if (i == ITEM_FILE)
@@ -203,7 +193,7 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
   if (count[INP_BYTES] == 0)
     bytes = 0;
   if (count[INP_CODE] == 0) {
-    outcome = SUCCESS;
+    outcome = TRUE;
     if (count[ITEM_FILE] == 2) {
       logfilep->data[LOGDATA_SUCC]++;
       logfilep->data[LOGDATA_SUCC7] += (unsigned long)last7;
@@ -216,26 +206,28 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
       logfilep->data[LOGDATA_UNKNOWN7] += (unsigned long)last7;
     }
   }
-  else switch (outcome = code2type[code]) {
-  case SUCCESS:
+  else if (code <= 199) {
+    outcome = INFO;
+    logfilep->data[LOGDATA_INFO]++;
+    logfilep->data[LOGDATA_INFO7] += (unsigned long)last7;
+  }
+  else if (code <= 299 || code == 304) {
+    outcome = TRUE;
     logfilep->data[LOGDATA_SUCC]++;
     logfilep->data[LOGDATA_SUCC7] += (unsigned long)last7;
     logfilep->data[LOGDATA_PAGES] += (unsigned long)ispage;
     logfilep->data[LOGDATA_PAGES7] +=
       (unsigned long)((logical)ispage && last7);
-    break;
-  case FAILURE:
-    logfilep->data[LOGDATA_FAIL]++;
-    logfilep->data[LOGDATA_FAIL7] += (unsigned long)last7;
-    break;
-  case REDIRECT:
+  }
+  else if (code <= 399) {
+    outcome = REDIRECT;
     logfilep->data[LOGDATA_REDIR]++;
     logfilep->data[LOGDATA_REDIR7] += (unsigned long)last7;
-    break;
-  case INFO:
-    logfilep->data[LOGDATA_INFO]++;
-    logfilep->data[LOGDATA_INFO7] += (unsigned long)last7;
-    break;
+  }
+  else {
+    outcome = FALSE;
+    logfilep->data[LOGDATA_FAIL]++;
+    logfilep->data[LOGDATA_FAIL7] += (unsigned long)last7;
   }
 
   /* NB any change in what to count when will require corresponding change to
@@ -243,7 +235,7 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
   if (count[INP_CODE] == 2)
     arrayscore(arraydata[REP_CODE - FIRST_ARRAYREP], code, 1, 0, 0., timecode);
   if (outcome != INFO) {
-    if (outcome == SUCCESS) {
+    if (outcome == TRUE) {
       if (count[INP_DATE] == 2)  /* only if file present: see strtoinfmt() */
 	datehash(timecode, dman, 1, (unsigned long)ispage, bytes, granularity);
       if (count[INP_BYTES] == 2) {
@@ -287,7 +279,7 @@ void process_data(Filelist *logfilep, FILE *lf, Hashtable **hash,
 		      convfloor, alldervs[i]);
 	}
       }
-    }    /* end if outcome == SUCCESS */
+    }    /* end if outcome == TRUE */
     for (i = 0; i < ITEM_NUMBER; i++) {
       if (count[i] == 2 && !ENTRY_BLANK(item[i]))
 	hashscore(item[i], outcome, last7, (logical)ispage, timecode, bytes);
