@@ -1,4 +1,4 @@
-/***             analog 4.1             http://www.analog.cx/             ***/
+/***             analog 4.04             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2000 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -88,10 +88,9 @@ int substrcasecmp(char *s, char *t) {
 }
 
 char *strtoupper(char *n) {
-  /* convert a string to upper case UP TO the first line break */
   char *c;
-  for (c = n; *c != '\0' && *c != '\n' && *c != '\r'; c++)
-    if (ISLOWER(*c))   /* needed to stop (known u.c.) const char *n crashing */
+  for (c = n; *c != '\0'; c++)
+    if (ISLOWER(*c))  /* this is needed to stop const char *n crashing */
       *c = TOUPPER(*c);
   return(n);
 }
@@ -103,16 +102,15 @@ void strtolowerx(char *n) {  /* only used in next 2 fns. */
 
 void toloweralias(Alias *ap, logical both) {
   AliasTo *tp;
-  char *errstr;
-  int erroffset;
 
   for ( ; ap != NULL; TO_NEXT(ap)) {
+#ifndef NOREGEX
     if (headcasematch(ap->from, "REGEXP:"))
-      ap->pattern = pcre_compile(ap->from + 7, PCRE_CASELESS | PCRE_DOTALL,
-				 (const char **)(&errstr), &erroffset, NULL);
+      regcomp(ap->pattern, ap->from + 7, REG_EXTENDED | REG_ICASE);
     /* if original regcomp succeeded, this one should too */
     else if (!headcasematch(ap->from, "REGEXPI:"))
       /* nothing to do for REGEXPI: */
+#endif
       strtolowerx(ap->from);
     if (both) {
       for (tp = ap->to; tp != NULL; TO_NEXT(tp))
@@ -123,14 +121,13 @@ void toloweralias(Alias *ap, logical both) {
 
 void tolowerinc(Include *ip) {
   /* see comments in previous function */
-  char *errstr;
-  int erroffset;
-
   for ( ; ip != NULL; TO_NEXT(ip)) {
+#ifndef NOREGEX
     if (headcasematch(ip->name, "REGEXP:"))
-      ip->pattern = pcre_compile(ip->name + 7, PCRE_CASELESS | PCRE_DOTALL,
-				 (const char **)(&errstr), &erroffset, NULL);
+      regcomp(ip->pattern, ip->name + 7,
+	      REG_EXTENDED | REG_ICASE | REG_NOSUB);
     else if (!headcasematch(ip->name, "REGEXPI:"))
+#endif
       strtolowerx((char *)(ip->name));
   }
 }
@@ -564,12 +561,12 @@ void *memmove(void *dst0, const void *src0, size_t length) {
 
 #define SETPMATCH(ptr1, ptr2) \
   if (nmatch > 0) { \
-    pmatch[0] = ptr1 - whole; \
-    pmatch[1] = ptr2 - whole; \
+    pmatch->rm_so = ptr1 - whole; \
+    pmatch->rm_eo = ptr2 - whole; \
   }
 
 logical wildmatch(char *s, char *p, char *whole, int nmatch,
-		  ptrdiff_t *pmatch) {  /* match string s against pattern p */
+		  regmatch_t *pmatch) {  /* match string s against pattern p */
   char *ss, *pp;
 
   /* First match head portions */
@@ -614,7 +611,7 @@ logical wildmatch(char *s, char *p, char *whole, int nmatch,
      (p was incremented above). We choose to match tail portion afresh each
      time (cheap), rather than insert null bytes into (poss. const) s and p */
   for (ss = s; *ss != '\0'; ss++) {   /* reuse ss */
-    if (wildmatch(ss, p, whole, nmatch - 2, pmatch + 2)) {
+    if (wildmatch(ss, p, whole, nmatch - 1, pmatch + 1)) {
       SETPMATCH(s, ss);
       return(TRUE);
     }
@@ -622,12 +619,14 @@ logical wildmatch(char *s, char *p, char *whole, int nmatch,
   return(FALSE);
 }
 
-logical matchq(char *s, void *p, logical is_regex, ptrdiff_t *pmatch) {
+logical matchq(char *s, void *p, logical is_regex, int nmatch,
+	       regmatch_t *pmatch) {
+#ifndef NOREGEX
   if (is_regex)
-    return(pcre_exec((pcre *)p, NULL, s, (int)strlen(s), 0, 0, (int *)pmatch,
-		     (pmatch == NULL)?0:PMATCH_SIZE) >= 0);
+    return(regexec((regex_t *)p, s, (size_t)nmatch, pmatch, 0) == 0);
   else
-    return(wildmatch(s, (char *)p, s, (pmatch == NULL)?0:PMATCH_SIZE, pmatch));
+#endif
+    return(wildmatch(s, (char *)p, s, nmatch, pmatch));
 }
 
 logical genwildmatch(char *s, char *s2, char *p) {
@@ -700,8 +699,12 @@ logical included(char *name, logical ispage, Include *listhead) {
 	return(IS_INC(lp->type));
     }
     else if (matchq(name,
+#ifdef NOREGEX
+		    (void *)(lp->name),
+#else
 		    is_regex?((void *)(lp->pattern)):((void *)(lp->name)),
-		    is_regex, NULL))
+#endif
+		    is_regex, 0, NULL))
       return(IS_INC(lp->type));
     lastlp = lp;
   }
@@ -714,9 +717,7 @@ logical pageq(char *name, Include *ispagehead, choice type) {
   char *c;
   logical ans;
 
-  if (type == ITEM_REFERRER)
-    return(TRUE);
-  if (type != ITEM_FILE)
+  if (type != ITEM_FILE && type != ITEM_REFERRER)
     return(FALSE);
 
   if ((c = strchr(name, '?')) != NULL) {
